%define pkgname		embree
%define api_version	3
%define libmajor	3
%define libname_orig	%mklibname %{pkgname} %{api_version}
%define libname		%mklibname %{pkgname} %{api_version} %{libmajor}
%define develname	%mklibname -d %{pkgname} %{api_version}
%define staticdevname	%mklibname -d -s %{pkgname} %{api_version}

# limit the maximum number of parallel building processes to avoid
# running out of memory during building
%global		_smp_ncpus_max 2

Name:		%{pkgname}%{api_version}
Version:	3.12.1
Release:	%mkrel 1
Summary:	A collection of high-performance ray tracing kernels
Group:		Graphics/3D
License:	ASL 2.0
URL:		https://embree.github.io
Source:		https://github.com/%{pkgname}/%{pkgname}/archive/v%{version}/%{pkgname}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	ispc
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(glfw3)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xmu)
# Use 64bit architectures because of SSE2 and up
ExclusiveArch:	x86_64

%description
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

%package -n %{libname}
Summary:	A collection of high-performance ray tracing kernels
Group:		System/Libraries
Requires:	%{_lib}tbb2 >= 4.0
Provides:	%{libname_orig} = %{version}-%{release}
Provides:	%{pkgname}%{api_version} = %{version}-%{release}

%description -n %{libname}
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

This package contains the library needed to run programs dynamically
linked with embree.

%package -n %{develname}
Summary:	Headers and development files of the embree library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{libname_orig}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the embree library. Install this package if you
want to compile applications using the embree library.

%prep
%autosetup -n %{pkgname}-%{version}

%build
%cmake \
	-DEMBREE_IGNORE_CMAKE_CXX_FLAGS:BOOL=OFF \
	-DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
	-DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
	-DEMBREE_RAY_MASK:BOOL=ON \
	-DEMBREE_BACKFACE_CULLING:BOOL=OFF \
	-DEMBREE_FILTER_FUNCTION:BOOL=ON \
	-DEMBREE_MAX_ISA:STRING="AVX512SKX" \
	-DEMBREE_TUTORIALS:BOOL=OFF

%if %{mgaversion} >= 8
%cmake_build
%else
%make_build
cd ..
%endif

%install
%if %{mgaversion} >= 8
%cmake_install
%else
%make_install -C build
%endif

# Remove installed doc files
rm -rf %{buildroot}%{_docdir}/%{name}

%files -n %{libname}
%{_libdir}/*.so.%{libmajor}{,.*}

%files -n %{develname}
%license LICENSE.txt
%doc README.md CHANGELOG.md readme.pdf
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/cmake/%{pkgname}-%{version}
%{_mandir}/man3/*


%changelog
* Sat Oct 17 2020 ghibo <ghibo> 3.12.1-1.mga8
+ Revision: 1636570
- Update to release 3.12.1

* Thu Oct 08 2020 ghibo <ghibo> 3.12.0-1.mga8
+ Revision: 1632889
- Update to release 3.12.0

* Sun Sep 13 2020 ghibo <ghibo> 3.11.0-2.mga8
+ Revision: 1625468
- Rebuild against ispc-1.14.1
- Update to release 3.11.0

* Sun May 31 2020 ghibo <ghibo> 3.10.0-1.mga8
+ Revision: 1589217
- Update to release 3.10
- Upgrade to release 3.9.0

* Sat Feb 15 2020 umeabot <umeabot> 3.5.2-3.mga8
+ Revision: 1526505
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon May 27 2019 ghibo <ghibo> 3.5.2-2.mga7
+ Revision: 1399254
- Enable EMBREE_RAY_MASK (needed for blender2.8).
- Try to increase number of parallel building processes to 2.

* Sun May 26 2019 ghibo <ghibo> 3.5.2-1.mga7
+ Revision: 1399223
- imported package embree3


* Sat May 25 2019 ghibo <ghibo> 3.5.2-1.mga7
- Initial release based on FC package.
- Mageia libification.
